@@ -1,11 +1,39 @@
 
 
+guiTextView <-
+    function(text, title = "Text View",
+             wrap.mode=c("none", "char", "word", "word_char"),
+             size=c(640, 400))
+{
+    wrap.mode <- match.arg(wrap.mode)
+    win <- gtkWindow(show = FALSE)
+    win["title"] <- title
+    win$setDefaultSize(size[1], size[2])
+    editTV <- gtkTextView()
+    setTextviewMonospace(editTV)
+    editTV$setWrapMode(GtkWrapMode[wrap.mode])
+    setTextview(editTV, text)
+    scroller <- gtkScrolledWindow()
+    scroller$add(editTV)
+    scroller$setPolicy(GtkPolicyType["automatic"], GtkPolicyType["automatic"])
+    win$add(scroller)
+    win$show()
+}
+
+        ## possible with gWidgets, but way too slow.
+        #txtBox <- gtext(callTxt, font.attr=c(family="monospace"), wrap=FALSE, width=600)
+        #gbasicdialog(title="Edit plot call", widget=txtBox,
+        #             action=environment(), handler=function(h, ...)
+        #             assign("newTxt", svalue(h[[1]]), env=h$action)
+        #             )
+
+
 guiTextInput <-
     function(text="",
              title="Text Input",
              prompt="",
-             oneLiner=F,
-             accepts.tab=T,
+             oneLiner=FALSE,
+             accepts.tab=TRUE,
              wrap.mode=c("none", "char", "word", "word_char"),
              size=c(640, 320),
              width.chars=-1,
@@ -15,14 +43,14 @@ guiTextInput <-
     ## construct dialog
     editBox <- gtkDialog(title=title, NULL, NULL,
                          "OK", GtkResponseType["ok"], "Cancel", GtkResponseType["cancel"],
-                         show = F)
+                         show = FALSE)
     editBox$setDefaultResponse(GtkResponseType["ok"])
     if (nchar(prompt) > 0) {
-        editBox$vbox$packStart(gtkLabel(prompt), expand=F, pad=2)
+        editBox$vbox$packStart(gtkLabel(prompt), expand=FALSE, pad=2)
     }
     if (oneLiner) {
         editEntry <- gtkEntry()
-        editEntry["activates-default"] <- T
+        editEntry["activates-default"] <- TRUE
         editEntry["text"] <- text
         editEntry["width-chars"] <- width.chars
         editBox$vbox$packStart(editEntry, pad=10)
